# coding: utf-8

"""
    Instana REST API documentation

    Documentation for INSTANA REST API

    The version of the OpenAPI document: 1.306.1368
    Contact: support@instana.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from instana_client.api.end_user_monitoring_api import EndUserMonitoringApi


class TestEndUserMonitoringApi(unittest.TestCase):
    """EndUserMonitoringApi unit test stubs"""

    def setUp(self) -> None:
        self.api = EndUserMonitoringApi()

    def tearDown(self) -> None:
        pass

    def test_get_impacted_users_report(self) -> None:
        """Test case for get_impacted_users_report

        Get impacted users report
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Instana REST API documentation

    Documentation for INSTANA REST API

    The version of the OpenAPI document: 1.306.1368
    Contact: support@instana.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from instana_client.api.service_levels_alert_configuration_api import ServiceLevelsAlertConfigurationApi


class TestServiceLevelsAlertConfigurationApi(unittest.TestCase):
    """ServiceLevelsAlertConfigurationApi unit test stubs"""

    def setUp(self) -> None:
        self.api = ServiceLevelsAlertConfigurationApi()

    def tearDown(self) -> None:
        pass

    def test_create_service_levels_alert_config(self) -> None:
        """Test case for create_service_levels_alert_config

        Create Service levels Alert Config
        """
        pass

    def test_delete_service_levels_alert_config(self) -> None:
        """Test case for delete_service_levels_alert_config

        Delete Service levels Alert Config
        """
        pass

    def test_disable_service_levels_alert_config(self) -> None:
        """Test case for disable_service_levels_alert_config

        Disable Service levels Alert Config
        """
        pass

    def test_enable_service_levels_alert_config(self) -> None:
        """Test case for enable_service_levels_alert_config

        Enable Service levels Alert Config
        """
        pass

    def test_find_active_service_levels_alert_configs(self) -> None:
        """Test case for find_active_service_levels_alert_configs

        All Service levels Alert Configs
        """
        pass

    def test_find_service_levels_alert_config(self) -> None:
        """Test case for find_service_levels_alert_config

        Get Service levels Alert Config
        """
        pass

    def test_find_service_levels_alert_config_versions(self) -> None:
        """Test case for find_service_levels_alert_config_versions

        Get versions of Service levels Alert Config
        """
        pass

    def test_restore_service_levels_alert_config(self) -> None:
        """Test case for restore_service_levels_alert_config

        Restore Service levels Alert Config
        """
        pass

    def test_update_service_levels_alert_config(self) -> None:
        """Test case for update_service_levels_alert_config

        Update Service levels Alert Config
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Instana REST API documentation

    Documentation for INSTANA REST API

    The version of the OpenAPI document: 1.306.1368
    Contact: support@instana.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from instana_client.api.user_api import UserApi


class TestUserApi(unittest.TestCase):
    """UserApi unit test stubs"""

    def setUp(self) -> None:
        self.api = UserApi()

    def tearDown(self) -> None:
        pass

    def test_get_invitations(self) -> None:
        """Test case for get_invitations

        All pending invitations
        """
        pass

    def test_get_user_by_id(self) -> None:
        """Test case for get_user_by_id

        Get single user
        """
        pass

    def test_get_users(self) -> None:
        """Test case for get_users

        All users (without invitations)
        """
        pass

    def test_get_users_including_invitations(self) -> None:
        """Test case for get_users_including_invitations

        All users (incl. invitations)
        """
        pass

    def test_invite_users(self) -> None:
        """Test case for invite_users

        Send user invitations
        """
        pass

    def test_remove_user_from_tenant(self) -> None:
        """Test case for remove_user_from_tenant

        Remove user from tenant
        """
        pass

    def test_remove_users_from_tenant(self) -> None:
        """Test case for remove_users_from_tenant

        Remove users from tenant
        """
        pass

    def test_revoke_pending_invitation(self) -> None:
        """Test case for revoke_pending_invitation

        Revoke pending invitation
        """
        pass

    def test_share_and_invite_users(self) -> None:
        """Test case for share_and_invite_users

        Send user invitations
        """
        pass

    def test_update_user(self) -> None:
        """Test case for update_user

        Change user name of single user
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Instana REST API documentation

    Documentation for INSTANA REST API

    The version of the OpenAPI document: 1.306.1368
    Contact: support@instana.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from instana_client.models.webhook_integration import WebhookIntegration

class TestWebhookIntegration(unittest.TestCase):
    """WebhookIntegration unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> WebhookIntegration:
        """Test WebhookIntegration
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `WebhookIntegration`
        """
        model = WebhookIntegration()
        if include_optional:
            return WebhookIntegration(
                headers = [
                    ''
                    ],
                oauth = instana_client.models.o_auth_integration.OAuthIntegration(
                    config = instana_client.models.o_auth_config.OAuthConfig(
                        additional_parameters = {
                            'key' : ''
                            }, 
                        client_id = '', 
                        client_secret = '', 
                        grant_type = 'CLIENT_CREDENTIALS', 
                        password = '', 
                        token_url = '', 
                        username = '', ), 
                    token = instana_client.models.o_auth_token.OAuthToken(
                        access_token = '', 
                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        expires_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        failed_refresh_attempts = 56, 
                        last_refresh_attempt = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        milliseconds_until_refresh_needed = 56, 
                        refresh_token = '', 
                        scope = '', 
                        status = 'VALID', 
                        token_type = '', 
                        updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        valid = True, ), ),
                oauth_enabled = True,
                transformation_expression = '',
                webhook_urls = [
                    ''
                    ]
            )
        else:
            return WebhookIntegration(
                webhook_urls = [
                    ''
                    ],
        )
        """

    def testWebhookIntegration(self):
        """Test WebhookIntegration"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
